==> teamapps-application-server-0.1-sources.jar: org/teamapps/model/controlcenter/UdbManagedApplicationPerspective.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.*;
import org.teamapps.universaldb.index.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.pojo.template.*;
import org.teamapps.universaldb.transaction.*;
import org.teamapps.universaldb.record.*;

import java.util.*;
import java.time.*;
import java.io.*;
import java.util.concurrent.*;
import java.util.function.Supplier;


public class UdbManagedApplicationPerspective extends AbstractUdbEntity<ManagedApplicationPerspective> implements ManagedApplicationPerspective {
	protected static TableIndex table;
	protected static IntegerIndex metaCreationDate;
	protected static IntegerIndex metaCreatedBy;
	protected static IntegerIndex metaModificationDate;
	protected static IntegerIndex metaModifiedBy;
	protected static IntegerIndex metaDeletionDate;
	protected static IntegerIndex metaDeletedBy;
	protected static SingleReferenceIndex managedApplication;
	protected static SingleReferenceIndex applicationPerspective;
	protected static TextIndex iconOverride;
	protected static TextIndex titleKeyOverride;
	protected static TextIndex descriptionKeyOverride;
	protected static IntegerIndex listingPosition;

    private static void setTableIndex(TableIndex tableIndex) {
        table = tableIndex;
		metaCreationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATION_DATE);
		metaCreatedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATED_BY);
		metaModificationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFICATION_DATE);
		metaModifiedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFIED_BY);
		metaDeletionDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETION_DATE);
		metaDeletedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETED_BY);
		managedApplication = (SingleReferenceIndex) tableIndex.getColumnIndex(FIELD_MANAGED_APPLICATION);
		applicationPerspective = (SingleReferenceIndex) tableIndex.getColumnIndex(FIELD_APPLICATION_PERSPECTIVE);
		iconOverride = (TextIndex) tableIndex.getColumnIndex(FIELD_ICON_OVERRIDE);
		titleKeyOverride = (TextIndex) tableIndex.getColumnIndex(FIELD_TITLE_KEY_OVERRIDE);
		descriptionKeyOverride = (TextIndex) tableIndex.getColumnIndex(FIELD_DESCRIPTION_KEY_OVERRIDE);
		listingPosition = (IntegerIndex) tableIndex.getColumnIndex(FIELD_LISTING_POSITION);
    }

    public static List<ManagedApplicationPerspective> getAll() {
        return new EntityBitSetList<>(ManagedApplicationPerspective.getBuilder(), table.getRecordBitSet());
    }

    public static List<ManagedApplicationPerspective> sort(List<ManagedApplicationPerspective> list, String sortFieldName, boolean ascending, String ... path) {
    	return sort(table, list, sortFieldName, ascending, path);
    }

    public static List<ManagedApplicationPerspective> sort(BitSet recordIds, String sortFieldName, boolean ascending, String ... path) {
        return sort(table, ManagedApplicationPerspective.getBuilder(), recordIds, sortFieldName, ascending, path);
    }

    public static int getCount() {
        return table.getCount();
    }

    public UdbManagedApplicationPerspective() {
        super(table);
    }

    public UdbManagedApplicationPerspective(int id, boolean createEntity) {
        super(table, id, createEntity);
    }

    @Override
    public ManagedApplicationPerspective build() {
        return new UdbManagedApplicationPerspective();
    }

    @Override
    public ManagedApplicationPerspective build(int id) {
        return new UdbManagedApplicationPerspective(id, false);
    }

	@Override
	public Instant getMetaCreationDate() {
	    return getTimestampValue(metaCreationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaCreationDate(Instant value) {
	    setTimestampValue(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaCreationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaCreationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaCreationDate);
		return this;
	}

	@Override
	public long getMetaCreationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaCreationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaCreationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreatedBy() {
        return getIntValue(metaCreatedBy);
	}

	@Override
	public ManagedApplicationPerspective setMetaCreatedBy(int value) {
	    setIntValue(value, this.metaCreatedBy);
		return this;
	}

	@Override
	public Instant getMetaModificationDate() {
	    return getTimestampValue(metaModificationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaModificationDate(Instant value) {
	    setTimestampValue(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModificationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaModificationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaModificationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaModificationDate);
		return this;
	}

	@Override
	public long getMetaModificationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaModificationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaModificationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModifiedBy() {
        return getIntValue(metaModifiedBy);
	}

	@Override
	public ManagedApplicationPerspective setMetaModifiedBy(int value) {
	    setIntValue(value, this.metaModifiedBy);
		return this;
	}

	@Override
	public Instant getMetaDeletionDate() {
	    return getTimestampValue(metaDeletionDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaDeletionDate(Instant value) {
	    setTimestampValue(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletionDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaDeletionDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaDeletionDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public long getMetaDeletionDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaDeletionDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaDeletionDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletedBy() {
        return getIntValue(metaDeletedBy);
	}

	@Override
	public ManagedApplicationPerspective setMetaDeletedBy(int value) {
	    setIntValue(value, this.metaDeletedBy);
		return this;
	}

	@Override
	public ManagedApplication getManagedApplication() {
		if (isChanged(managedApplication)) {
			return (ManagedApplication) getReferenceChangeValue(managedApplication);
		} else {
			int id = managedApplication.getValue(getId());
			if (id > 0) {
				return ManagedApplication.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public ManagedApplicationPerspective setManagedApplication(ManagedApplication value) {
		setSingleReferenceValue(managedApplication, value, table);
		return this;
	}

	@Override
	public ApplicationPerspective getApplicationPerspective() {
		if (isChanged(applicationPerspective)) {
			return (ApplicationPerspective) getReferenceChangeValue(applicationPerspective);
		} else {
			int id = applicationPerspective.getValue(getId());
			if (id > 0) {
				return ApplicationPerspective.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public ManagedApplicationPerspective setApplicationPerspective(ApplicationPerspective value) {
		setSingleReferenceValue(applicationPerspective, value, table);
		return this;
	}

	@Override
	public String getIconOverride() {
        return getTextValue(iconOverride);
	}

	@Override
	public ManagedApplicationPerspective setIconOverride(String value) {
	    setTextValue(value, this.iconOverride);
		return this;
	}

	@Override
	public String getTitleKeyOverride() {
        return getTextValue(titleKeyOverride);
	}

	@Override
	public ManagedApplicationPerspective setTitleKeyOverride(String value) {
	    setTextValue(value, this.titleKeyOverride);
		return this;
	}

	@Override
	public String getDescriptionKeyOverride() {
        return getTextValue(descriptionKeyOverride);
	}

	@Override
	public ManagedApplicationPerspective setDescriptionKeyOverride(String value) {
	    setTextValue(value, this.descriptionKeyOverride);
		return this;
	}

	@Override
	public int getListingPosition() {
        return getIntValue(listingPosition);
	}

	@Override
	public ManagedApplicationPerspective setListingPosition(int value) {
	    setIntValue(value, this.listingPosition);
		return this;
	}


    @Override
    public UdbManagedApplicationPerspective save(Transaction transaction, boolean strictChangeVerification) {
        save(transaction, table, strictChangeVerification);
        return this;
    }

    @Override
    public UdbManagedApplicationPerspective saveTransactional(boolean strictChangeVerification) {
        save(UniversalDB.getThreadLocalTransaction(), table, strictChangeVerification);
        return this;
    }

    @Override
    public UdbManagedApplicationPerspective save() {
        save(table);
        return this;
    }

    @Override
    public void delete(Transaction transaction) {
        delete(transaction, table);
    }

    @Override
    public void delete() {
        delete(table);
    }

	@Override
	public String toString() {
    	StringBuilder sb = new StringBuilder();
    	sb.append(table.getName()).append(": ").append(getId()).append("\n");
		for (ColumnIndex column : table.getColumnIndices()) {
			sb.append("\t").append(column.getName()).append(": ").append(column.getStringValue(getId()));
			if (isChanged(column)) {
				TransactionRecordValue changeValue = getChangeValue(column);
				sb.append(" -> ").append(changeValue.getValue());
			}
			sb.append("\n");
		}
		return sb.toString();
	}
}

==> teamapps-application-server-0.3-sources.jar: org/teamapps/model/controlcenter/UdbManagedApplicationPerspective.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.*;
import org.teamapps.universaldb.index.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.pojo.template.*;
import org.teamapps.universaldb.transaction.*;
import org.teamapps.universaldb.record.*;

import java.util.*;
import java.time.*;
import java.io.*;
import java.util.concurrent.*;
import java.util.function.Supplier;


public class UdbManagedApplicationPerspective extends AbstractUdbEntity<ManagedApplicationPerspective> implements ManagedApplicationPerspective {
	protected static TableIndex table;
	protected static IntegerIndex metaCreationDate;
	protected static IntegerIndex metaCreatedBy;
	protected static IntegerIndex metaModificationDate;
	protected static IntegerIndex metaModifiedBy;
	protected static IntegerIndex metaDeletionDate;
	protected static IntegerIndex metaDeletedBy;
	protected static SingleReferenceIndex managedApplication;
	protected static SingleReferenceIndex applicationPerspective;
	protected static TextIndex iconOverride;
	protected static TextIndex titleKeyOverride;
	protected static TextIndex descriptionKeyOverride;
	protected static BooleanIndex toolbarPerspectiveMenu;
	protected static IntegerIndex listingPosition;

    private static void setTableIndex(TableIndex tableIndex) {
        table = tableIndex;
		metaCreationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATION_DATE);
		metaCreatedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATED_BY);
		metaModificationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFICATION_DATE);
		metaModifiedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFIED_BY);
		metaDeletionDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETION_DATE);
		metaDeletedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETED_BY);
		managedApplication = (SingleReferenceIndex) tableIndex.getColumnIndex(FIELD_MANAGED_APPLICATION);
		applicationPerspective = (SingleReferenceIndex) tableIndex.getColumnIndex(FIELD_APPLICATION_PERSPECTIVE);
		iconOverride = (TextIndex) tableIndex.getColumnIndex(FIELD_ICON_OVERRIDE);
		titleKeyOverride = (TextIndex) tableIndex.getColumnIndex(FIELD_TITLE_KEY_OVERRIDE);
		descriptionKeyOverride = (TextIndex) tableIndex.getColumnIndex(FIELD_DESCRIPTION_KEY_OVERRIDE);
		toolbarPerspectiveMenu = (BooleanIndex) tableIndex.getColumnIndex(FIELD_TOOLBAR_PERSPECTIVE_MENU);
		listingPosition = (IntegerIndex) tableIndex.getColumnIndex(FIELD_LISTING_POSITION);
    }

    public static List<ManagedApplicationPerspective> getAll() {
        return new EntityBitSetList<>(ManagedApplicationPerspective.getBuilder(), table.getRecordBitSet());
    }

    public static List<ManagedApplicationPerspective> sort(List<ManagedApplicationPerspective> list, String sortFieldName, boolean ascending, String ... path) {
    	return sort(table, list, sortFieldName, ascending, path);
    }

    public static List<ManagedApplicationPerspective> sort(BitSet recordIds, String sortFieldName, boolean ascending, String ... path) {
        return sort(table, ManagedApplicationPerspective.getBuilder(), recordIds, sortFieldName, ascending, path);
    }

    public static int getCount() {
        return table.getCount();
    }

    public UdbManagedApplicationPerspective() {
        super(table);
    }

    public UdbManagedApplicationPerspective(int id, boolean createEntity) {
        super(table, id, createEntity);
    }

    @Override
    public ManagedApplicationPerspective build() {
        return new UdbManagedApplicationPerspective();
    }

    @Override
    public ManagedApplicationPerspective build(int id) {
        return new UdbManagedApplicationPerspective(id, false);
    }

	@Override
	public Instant getMetaCreationDate() {
	    return getTimestampValue(metaCreationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaCreationDate(Instant value) {
	    setTimestampValue(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaCreationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaCreationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaCreationDate);
		return this;
	}

	@Override
	public long getMetaCreationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaCreationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaCreationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreatedBy() {
        return getIntValue(metaCreatedBy);
	}

	@Override
	public ManagedApplicationPerspective setMetaCreatedBy(int value) {
	    setIntValue(value, this.metaCreatedBy);
		return this;
	}

	@Override
	public Instant getMetaModificationDate() {
	    return getTimestampValue(metaModificationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaModificationDate(Instant value) {
	    setTimestampValue(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModificationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaModificationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaModificationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaModificationDate);
		return this;
	}

	@Override
	public long getMetaModificationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaModificationDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaModificationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModifiedBy() {
        return getIntValue(metaModifiedBy);
	}

	@Override
	public ManagedApplicationPerspective setMetaModifiedBy(int value) {
	    setIntValue(value, this.metaModifiedBy);
		return this;
	}

	@Override
	public Instant getMetaDeletionDate() {
	    return getTimestampValue(metaDeletionDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaDeletionDate(Instant value) {
	    setTimestampValue(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletionDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaDeletionDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaDeletionDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public long getMetaDeletionDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaDeletionDate);
	}

	@Override
	public ManagedApplicationPerspective setMetaDeletionDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletedBy() {
        return getIntValue(metaDeletedBy);
	}

	@Override
	public ManagedApplicationPerspective setMetaDeletedBy(int value) {
	    setIntValue(value, this.metaDeletedBy);
		return this;
	}

	@Override
	public ManagedApplication getManagedApplication() {
		if (isChanged(managedApplication)) {
			return (ManagedApplication) getReferenceChangeValue(managedApplication);
		} else {
			int id = managedApplication.getValue(getId());
			if (id > 0) {
				return ManagedApplication.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public ManagedApplicationPerspective setManagedApplication(ManagedApplication value) {
		setSingleReferenceValue(managedApplication, value, table);
		return this;
	}

	@Override
	public ApplicationPerspective getApplicationPerspective() {
		if (isChanged(applicationPerspective)) {
			return (ApplicationPerspective) getReferenceChangeValue(applicationPerspective);
		} else {
			int id = applicationPerspective.getValue(getId());
			if (id > 0) {
				return ApplicationPerspective.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public ManagedApplicationPerspective setApplicationPerspective(ApplicationPerspective value) {
		setSingleReferenceValue(applicationPerspective, value, table);
		return this;
	}

	@Override
	public String getIconOverride() {
        return getTextValue(iconOverride);
	}

	@Override
	public ManagedApplicationPerspective setIconOverride(String value) {
	    setTextValue(value, this.iconOverride);
		return this;
	}

	@Override
	public String getTitleKeyOverride() {
        return getTextValue(titleKeyOverride);
	}

	@Override
	public ManagedApplicationPerspective setTitleKeyOverride(String value) {
	    setTextValue(value, this.titleKeyOverride);
		return this;
	}

	@Override
	public String getDescriptionKeyOverride() {
        return getTextValue(descriptionKeyOverride);
	}

	@Override
	public ManagedApplicationPerspective setDescriptionKeyOverride(String value) {
	    setTextValue(value, this.descriptionKeyOverride);
		return this;
	}

	@Override
	public boolean getToolbarPerspectiveMenu() {
	    return getBooleanValue(toolbarPerspectiveMenu);
	}

	@Override
	public ManagedApplicationPerspective setToolbarPerspectiveMenu(boolean value) {
	    setBooleanValue(value, this.toolbarPerspectiveMenu);
		return this;
	}

	@Override
	public boolean isToolbarPerspectiveMenu() {
	    return getBooleanValue(toolbarPerspectiveMenu);
	}

	@Override
	public int getListingPosition() {
        return getIntValue(listingPosition);
	}

	@Override
	public ManagedApplicationPerspective setListingPosition(int value) {
	    setIntValue(value, this.listingPosition);
		return this;
	}


    @Override
    public UdbManagedApplicationPerspective save(Transaction transaction, boolean strictChangeVerification) {
        save(transaction, table, strictChangeVerification);
        return this;
    }

    @Override
    public UdbManagedApplicationPerspective saveTransactional(boolean strictChangeVerification) {
        save(UniversalDB.getThreadLocalTransaction(), table, strictChangeVerification);
        return this;
    }

    @Override
    public UdbManagedApplicationPerspective save() {
        save(table);
        return this;
    }

    @Override
    public void delete(Transaction transaction) {
        delete(transaction, table);
    }

    @Override
    public void delete() {
        delete(table);
    }
}
